@@ -29,7 +29,7 @@ class WechatWebhookOptionsForm(notify.NotificationConfigurationForm):
 class MultiWechatWebhookPlugin(notify.NotificationPlugin):
     author = 'badx'
     author_url = 'https://github.com/badx/sentry-multi-webhook'
-    version = '0.0.14'
+    version = '0.0.15'
     description = u'Sentry 企业微信 Webhook 插件'
     resource_links = [
         ('Source', 'https://github.com/badx/sentry-multi-webhook'),
@@ -74,9 +74,8 @@ class MultiWechatWebhookPlugin(notify.NotificationPlugin):
             }
         }
         print("title:%s, data:%s" % (title, json.dumps(data).encode("utf-8")))
-        requests.post(
+        print("result:%s", json.dumps(requests.post(
             url=url,
             headers={"Content-Type": "application/json"},
             data=json.dumps(data).encode("utf-8")
-        )
-        print("result%s", json.dumps(requests.json()))
+        ).json()))
